# This script imports data from *.xlsx files exported by Tecan Reader (Tecan Trading AG, Switzerland, Spark 10M, SparkControl V 2.1) .
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223

library(tidyverse)
library(readxl)

#import raw data and filter the relevant rows and columns
Plate1 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 1.xlsx", range = "A25:F46", col_names = FALSE)) %>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate1_2 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 1.xlsx", range = "A59:F81", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate2 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 2.xlsx", range = "A25:F46", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate2_2 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 2.xlsx", range = "A59:F81", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate3 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 3.xlsx", range = "A25:F46", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate3_2 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 3.xlsx", range = "A59:F81", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate4 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 4.xlsx", range = "A26:F47", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate4_2 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 4.xlsx", range = "A60:F82", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate4_3 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 4.xlsx", range = "A94:F117", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate5 <- as.tibble(read_excel("20180618 siRNA-Cy5 1203-Atto488 Fret Plate 5.xlsx", range = "A24:F47", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate6 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223 1224.xlsx", range = "A26:F49", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate6_2 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223 1224.xlsx", range = "A60:F83", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate6_3 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223 1224.xlsx", range = "A94:F117", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate7 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223.xlsx", range = "A26:F49", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate7_2 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223.xlsx", range = "A60:F83", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))
Plate7_3 <- as.tibble(read_excel("20180630 FRET Atto488 Cy5 991 1203 1223.xlsx", range = "A94:F117", col_names = FALSE))%>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D"))

# name samples, controls and panels
samples <- c("core-Cy5" , "core", "core-Cy5_2", "1203-Atto488", "core 1203-Atto488", "core-Cy5 1203-Atto488",  "1223-Atto488", "core 1223-Atto488","core-Cy5 1223-Atto488", "1224-Atto488",   "core 1224-Atto488",  "core-Cy5 1224-Atto488", "HbG 5% Ac")
controls <- c("siRNA-Cy5 0.1",  "1203-Atto488 0.1", "siRNA-Cy5 1203-Atto488 0.05", "siRNA-Cy5 0.01", "1203-Atto488 0.01", "siRNA-Cy5 1203-Atto488 0.005", "siRNA-Cy5 0.001", "1203-Atto488 0.001" , "siRNA-Cy5 1203-Atto488 0.0005",  "water")
panels <- c("Atto488\nex: 485, em: 535", "Cy5\nex: 625, em: 680", "FRET\nex: 485, em: 680")


#transform data into tidy format and place data in appropriately named rows
Plate1_tidy <- Plate1 %>% 
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[1],controls[4], controls[7]) ) %>%
  mutate (gain = as.double(Plate1[4,5])) %>%
  mutate (ex = as.double(Plate1[2,5])) %>%
  mutate (em = as.double(Plate1[3,5])) %>%
  mutate ( measurement = as.character(Plate1[1,2])) 

Plate1_2_tidy <- Plate1_2 %>% 
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[2],controls[5], controls[8]) ) %>%
  mutate (gain = as.double(Plate1_2[4,5])) %>%
  mutate (ex = as.double(Plate1_2[2,5])) %>%
  mutate (em = as.double(Plate1_2[3,5])) %>%
  mutate ( measurement = as.character(Plate1_2[1,2]))

Plate2_tidy <- Plate2 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[1],controls[4], controls[7]) ) %>%
  mutate (gain = as.double(Plate2[4,5])) %>%
  mutate (ex = as.double(Plate2[2,5])) %>%
  mutate (em = as.double(Plate2[3,5])) %>%
  mutate ( measurement = as.character(Plate2[1,2]))

Plate2_2_tidy <- Plate2_2 %>% 
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[2],controls[5], controls[8]) ) %>%
  mutate (gain = as.double(Plate2_2[4,5])) %>%
  mutate (ex = as.double(Plate2_2[2,5])) %>%
  mutate (em = as.double(Plate2_2[3,5])) %>%
  mutate ( measurement = as.character(Plate2_2[1,2]))

Plate3_tidy <- Plate3 %>% 
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[1],controls[4], controls[7]) ) %>%
  mutate (gain = as.double(Plate3[4,5])) %>%
  mutate (ex = as.double(Plate3[2,5])) %>%
  mutate (em = as.double(Plate3[3,5])) %>%
  mutate ( measurement = as.character(Plate3[1,2]))

Plate3_2_tidy <- Plate3_2 %>% 
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[2],controls[5], controls[8]) ) %>%
  mutate (gain = as.double(Plate3_2[4,5])) %>%
  mutate (ex = as.double(Plate3_2[2,5])) %>%
  mutate (em = as.double(Plate3_2[3,5])) %>%
  mutate ( measurement = as.character(Plate3_2[1,2]))

Plate4_tidy <- Plate4 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[1],controls[4], controls[7], controls[10]) ) %>%
  mutate (gain = as.double(Plate4[4,5])) %>%
  mutate (ex = as.double(Plate4[2,5])) %>%
  mutate (em = as.double(Plate4[3,5])) %>%
  mutate ( measurement = as.character(Plate4[1,2]))

Plate4_2_tidy <- Plate4_2 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[2],controls[5], controls[8]) ) %>%
  mutate (gain = as.double(Plate4_2[4,5])) %>%
  mutate (ex = as.double(Plate4_2[2,5])) %>%
  mutate (em = as.double(Plate4_2[3,5])) %>%
  mutate ( measurement = as.character(Plate4_2[1,2]))

Plate4_3_tidy <- Plate4_3 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[3],controls[6], controls[9]) ) %>%
  mutate (gain = as.double(Plate4_3[4,5])) %>%
  mutate (ex = as.double(Plate4_3[2,5])) %>%
  mutate (em = as.double(Plate4_3[3,5])) %>%
  mutate ( measurement = as.character(Plate4_3[1,2]))

Plate5_tidy <- Plate5 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(controls[1:10]) ) %>%
  mutate (gain = as.double(Plate5[4,5])) %>%
  mutate (ex = as.double(Plate5[2,5])) %>%
  mutate (em = as.double(Plate5[3,5])) %>%
  mutate ( measurement = as.character(Plate5[1,2]))

Plate6_tidy <- Plate6 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:13]) ) %>%
  mutate (gain = as.double(Plate6[4,5])) %>%
  mutate (ex = as.double(Plate6[2,5])) %>%
  mutate (em = as.double(Plate6[3,5])) %>%
  mutate ( measurement = as.character(Plate6[1,2]))

Plate6_2_tidy <- Plate6_2 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:13]) ) %>%
  mutate (gain = as.double(Plate6_2[4,5])) %>%
  mutate (ex = as.double(Plate6_2[2,5])) %>%
  mutate (em = as.double(Plate6_2[3,5]))%>%
  mutate (measurement = as.character(Plate6_2[1,2]))

Plate6_3_tidy <- Plate6_3 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:13]) ) %>%
  mutate (gain = as.double(Plate6_3[4,5])) %>%
  mutate (ex = as.double(Plate6_3[2,5])) %>%
  mutate (em = as.double(Plate6_3[3,5])) %>%
  mutate ( measurement = as.character(Plate6_3[1,2]))


Plate7_tidy <- Plate7 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:13]) ) %>%
  mutate (gain = as.double(Plate7[4,5])) %>%
  mutate (ex = as.double(Plate7[2,5])) %>%
  mutate (em = as.double(Plate7[3,5])) %>%
  mutate ( measurement = as.character(Plate7[1,2]))

Plate7_2_tidy <- Plate7_2 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:10]) ) %>%
  mutate (gain = as.double(Plate7_2[4,5])) %>%
  mutate (ex = as.double(Plate7_2[2,5])) %>%
  mutate (em = as.double(Plate7_2[3,5]))%>%
  mutate (measurement = as.character(Plate7_2[1,2]))

Plate7_3_tidy <- Plate7_3 %>%
  filter(`X__1` %in% c("A", "B", "C")) %>%
  gather(`X__2`:`X__6`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  mutate(fluorescence = as.double(fluorescence)) %>%
  mutate(sample = c(samples[1:10]) ) %>%
  mutate (gain = as.double(Plate7_3[4,5])) %>%
  mutate (ex = as.double(Plate7_3[2,5])) %>%
  mutate (em = as.double(Plate7_3[3,5])) %>%
  mutate ( measurement = as.character(Plate7_3[1,2]))

# combine control values in one tibble
FRET_ctrl <- rbind(Plate5_tidy, Plate4_tidy, Plate4_2_tidy, Plate4_3_tidy, Plate3_tidy, Plate3_2_tidy, Plate2_tidy, Plate2_2_tidy, Plate1_tidy, Plate1_2_tidy) %>%
  filter(ex != 360) %>%
  mutate(experiment = "ctrl") %>%
  mutate("c [mg/ml]" = str_extract(sample, "\\d\\.\\d{1,4}")) %>%
  replace_na(list("c [mg/ml]" = 0))

# combine samples into a tibble and remove unwanted samples
FRET_1 <- rbind (Plate6_tidy, Plate6_2_tidy, Plate6_3_tidy)  %>%  
  filter(!str_detect(sample, pattern = "1224")) %>% # removes samples containing 1224 shell because it is not included in the manuscript
  mutate(experiment = "FRET_1") %>%
  mutate("c [mg/ml]" = ifelse(str_detect(sample, "HbG 5% Ac"), 0, 0.01))

FRET_2 <- rbind (Plate7_tidy, Plate7_2_tidy, Plate7_3_tidy) %>%  
  filter(!str_detect(sample, pattern = "1224"))%>%
  mutate(experiment = "FRET_2") %>%
  mutate("c [mg/ml]" = ifelse(str_detect(sample, "HbG 5% Ac"), 0, 0.01))
  
#combine sample's data mutate it to be more specific.
FRET <- rbind(FRET_1, FRET_2, FRET_ctrl) %>%
  mutate("fluor/gain" = fluorescence / gain)%>%
  mutate(measurement = ifelse(measurement != "FRET Cy5 Atto 488" , measurement, "FRET")) %>%
  mutate(label = ifelse(fluorescence > 500, measurement, 0))

# spit sample's data according to measurement to be able to label it accordingly
FRET_FRET <- FRET %>%
  filter(measurement == "FRET") %>%
  mutate(label = ifelse(str_detect(sample, "Atto488|Cy5") , str_extract(sample, "Cy5|Atto488"), label)) %>%
  mutate(label = ifelse(str_detect(sample, "Cy5.*Atto488"), "Cy5, Atto488", label))
 
FRET_Cy5 <- FRET %>%
  filter(measurement == "Cy5") %>%
  mutate(label = ifelse(str_detect(sample, "Cy5.*Atto488"), "Cy5, Atto488", label))

FRET_Atto488 <- FRET %>%
  filter(measurement == "Atto488") %>%
  mutate(label = ifelse(str_detect(sample, "Cy5.*Atto488"), "Cy5, Atto488", label))

# combine sample's data again    
FRET_data <- rbind(FRET_Cy5, FRET_Atto488, FRET_FRET) 

#extract parts of the sample name to define components accordingly
FRET_data_components <- as_tibble(cbind(
str_extract(FRET_data$sample, "core"),
str_extract(FRET_data$sample, "1203"),
str_extract(FRET_data$sample, "1223"),
str_extract(FRET_data$sample, "siRNA"),
str_extract(FRET_data$sample, "HbG 5% Ac"),
str_extract(FRET_data$sample, "water")
)) %>%
mutate(components = str_c(str_replace_na(V1, ""), 
                              str_replace_na(V2, ""), 
                              str_replace_na(V3, ""),
                              str_replace_na(V4, ""),
                              str_replace_na(V5, ""),
                              str_replace_na(V6, ""),
                              sep = "")) %>%
  select(components)

#include the new column "components" into FRET_data
FRET_data <- as.tibble(cbind(FRET_data, FRET_data_components))

#prepare FRET ctrl plot data
FRET_ctrl_data <- FRET_data %>%
  filter(label != "Cy5, Atto488") %>%
  mutate(label_name = ifelse(label == "Cy5", "siRNA-Cy5", "lipid anchor-\nAtto488" )) %>%
  mutate(label_name = ifelse(label == "0", "none", label_name )) %>%
  mutate(label_name = factor(label_name, levels = c("none","lipid anchor-\nAtto488", "siRNA-Cy5"))) %>%
  filter(`c [mg/ml]` == 0.01  | `c [mg/ml]` == 0.005  | `c [mg/ml]` == 0) %>%
  mutate(label = ifelse(str_detect(sample, "water"), 0, label)) %>%
  filter (components != "water") %>%
  mutate(panel = ifelse(measurement == "Atto488", panels[1], panels[2])) %>%
  mutate(panel = ifelse(measurement == "FRET", panels[3], panel))

# turn "components" into a factor to control order of x-axis
FRET_ctrl_data$components <- factor(
  FRET_ctrl_data$components,
  levels = levels(as.factor(FRET_ctrl_data$components)), 
  labels = c("LA", "LAE", "core", "core LA", "core LAE", "HBG", "siRNA") )

# FRET sample plot data
FRET_sample_data <- FRET_data %>%
  filter(label == "Cy5, Atto488") %>%
  mutate(label_name = "siRNA-Cy5\nlipid anchor-Atto488" ) %>%
  filter(`c [mg/ml]` == 0.01  | `c [mg/ml]` == 0.005  | `c [mg/ml]` == 0) %>%
  mutate(panel = ifelse(measurement == "Atto488", panels[1], panels[2])) %>%
  mutate(panel = ifelse(measurement == "FRET", panels[3], panel))

# turn "sample" into a factor to control order of x-axis
FRET_sample_data$sample <- factor(FRET_sample_data$sample, levels = c("core-Cy5 1203-Atto488", "core-Cy5 1223-Atto488", "siRNA-Cy5 1203-Atto488 0.005"), labels =  c("core +\nLA", "core + \nLAE", "siRNA + \nLA"))

#definw colours
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey. From colour brewer

# plots - controls
pSI_FRET <- ggplot (FRET_ctrl_data, aes(components, `fluor/gain`, colour = label_name, shape = label_name) ) + 
  stat_summary(fun.y = mean, geom = "point", size = 3) + 
  facet_grid(~panel, 
             scales = "free_x", 
             space = "free_x"
  ) + 
  labs(
    x = "formulation",
    y = "fluorescence / gain",
    subtitle = "FRET control measurements from core - lipid anchor polyplexes",
    colour = NULL,
    fill = NULL,
    tag = NULL,
    caption = "Assembly: pipettes (core) + SMC"
  ) +
  theme_bw(
  ) +
  theme(
    axis.text.x=element_text(angle=45,hjust=1),
    legend.background = element_rect(size = 0.5, colour = "grey50")
    ) +
  scale_y_continuous (
    limits = c(0,800)
  ) +
  scale_colour_discrete(
    name = "dye"
  ) + 
  scale_shape_manual(name = "dye", values=c(17,16,18)
                     ) 

# plots - samples
p4A <- ggplot (FRET_sample_data, aes(sample, `fluor/gain`, colour = label_name) ) + 
  stat_summary(fun.y = mean, geom = "point", size = 3) +
  facet_grid(~panel, 
             scales = "free_x", 
             space = "free_x"
  ) + 
  labs(
    x = "formulation",
    y = "fluorescence / gain",
    title = "FRET measurements from core - lipid anchor polyplexes",
    colour = NULL,
    fill = NULL,
    tag = "A",
    caption = "Assembly: pipettes (core) + SMC"
  ) +
  theme_bw(
  ) +
  theme(
    legend.position = c(0.14, 0.85), # centered: 0.14, 0.9
    legend.background = element_rect(size = 0.5, colour = "grey50"),
    legend.key = element_rect(color = "grey50")
  )+
  scale_y_continuous (
    limits = c(0,800)
  ) +
  scale_colour_discrete(
    name = "dye"
  )

# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# save plots as .png
ggsave("Figure4.png", plot = p4A,  width = 16.1, height = 9, units = c("cm"), dpi = 300, device = NULL)
ggsave("Supplemental_figure_S17_FRET_ctrls.png", plot = pSI_FRET,  width = 16, height = 9, units = c("cm"), dpi = 300, device = NULL)

