# This script imports data from *.xlsx files exported by Tecan Reader (Tecan Trading AG, Switzerland, Spark 10M, SparkControl V 2.1).
# The data is transformed into a tidy format and plotted with ggplot.
# Oligomers are named with their ids: CON: 1106
library(tidyverse)
library(readxl)

setwd() # choose the folder where the raw data is stored

# specify core
core_all <- c("454", "1106")
ligand_all <- c("DF", "DP3F", "DP12F", "DP24F", "DP48F")

# specify id for plotting the data (sample names on x axis)
id_all <- c("HBG", "core\npolyplex", "F", "P3F", "P12F", "P24F", "P48F")

# define sample names
sample_names_plate1 <- c("454", "1106")
sample_names_plate2 <- c("1106 + 25% DF", "1106 + 25% DP3F", "1106 + 25% DP12F", "1106 + 25% DP24F", "1106 + 25% DP48F")
sample_names_plate3 <- c("1106 + 50% DF", "1106 + 50% DP3F", "1106 + 50% DP12F", "1106 + 50% DP24F", "1106 + 50% DP48F")
sample_names_plate4 <- c("1106 + 75% DF", "1106 + 75% DP3F", "1106 + 75% DP12F", "1106 + 75% DP24F", "1106 + 75% DP48F")
sample_names_plate5 <- c("1106 + 100% DF", "1106 + 100% DP3F", "1106 + 100% DP12F", "1106 + 100% DP24F", "1106 + 100% DP48F")

#import raw data
Plate1 <- as.tibble(read_excel("20181109 MTT Assay 1106 D1PEG0-48-FolA Plate1.xlsx",
                               range = "C64:L66",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:3])
Plate2 <- as.tibble(read_excel("20181109 MTT Assay 1106 D1PEG0-48-FolA Plate2.xlsx",
                               range = "C61:L66",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:6])
Plate3 <- as.tibble(read_excel("20181109 MTT Assay 1106 D1PEG0-48-FolA Plate3.xlsx",
                               range = "C61:L66",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:6])


Plate4 <- as.tibble(read_excel("20181109 MTT Assay 1106 D1PEG0-48-FolA Plate4.xlsx",
                               range = "C61:L66",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:6])
Plate5 <- as.tibble(read_excel("20181109 MTT Assay 1106 D1PEG0-48-FolA Plate5.xlsx",
                               range = "C61:L66",
                               col_names = FALSE)
)%>%
  mutate(row = LETTERS[1:6])

# tidy up the data
Plate1_tidy <- Plate1 %>%
  gather(`X__1`:`X__10`, key = "col", value = "fluorescence") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>%
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate1[1], "HBG1" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate1[2], sample )) %>%
  mutate (id = ifelse(row == "A" , id_all[1], id_all[2])) %>% #  add id for plotting nice graphs according to id
  mutate ("%" = 0)  

Plate2_tidy <- Plate2 %>% 
  gather(`X__1`:`X__10`, key = "col", value = "fluorescence") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>% 
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate2[1], "HBG2" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate2[2], sample )) %>%
  mutate (sample = ifelse(row == "D",sample_names_plate2[3], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate2[4], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate2[5], sample )) %>%
  mutate (id = ifelse(row == "A", id_all[1], id_all[3])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "C" , id_all[4], id)) %>%
  mutate (id = ifelse(row == "D" , id_all[5], id)) %>%
  mutate (id = ifelse(row == "E" , id_all[6], id)) %>%
  mutate (id = ifelse(row == "F" , id_all[7], id)) %>%
  mutate ("%" = ifelse (group == "HBG", 0, 25))

Plate3_tidy <- Plate3 %>% 
  gather(`X__1`:`X__10`, key = "col", value = "fluorescence") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>% 
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate3[1], "HBG3" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate3[2], sample )) %>%
  mutate (sample = ifelse(row == "D",sample_names_plate3[3], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate3[4], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate3[5], sample )) %>%
  mutate (id = ifelse(row == "A", id_all[1], id_all[3])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "C" , id_all[4], id)) %>%
  mutate (id = ifelse(row == "D" , id_all[5], id)) %>%
  mutate (id = ifelse(row == "E" , id_all[6], id)) %>%
  mutate (id = ifelse(row == "F" , id_all[7], id)) %>%
  mutate ("%" = ifelse (group == "HBG", 0, 50))

Plate4_tidy <- Plate4 %>% 
  gather(`X__1`:`X__10`, key = "col", value = "fluorescence") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>% 
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate4[1], "HBG4" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate4[2], sample )) %>%
  mutate (sample = ifelse(row == "D",sample_names_plate4[3], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate4[4], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate4[5], sample )) %>%
  mutate (id = ifelse(row == "A", id_all[1], id_all[3])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "C" , id_all[4], id)) %>%
  mutate (id = ifelse(row == "D" , id_all[5], id)) %>%
  mutate (id = ifelse(row == "E" , id_all[6], id)) %>%
  mutate (id = ifelse(row == "F" , id_all[7], id)) %>%
  mutate ("%" = ifelse (group == "HBG", 0, 75))

Plate5_tidy <- Plate5 %>% 
  gather(`X__1`:`X__10`, key = "col", value = "fluorescence") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>% 
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate5[1], "HBG5" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate5[2], sample )) %>%
  mutate (sample = ifelse(row == "D",sample_names_plate5[3], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate5[4], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate5[5], sample )) %>%
  mutate (id = ifelse(row == "A", id_all[1], id_all[3])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "C" , id_all[4], id)) %>%
  mutate (id = ifelse(row == "D" , id_all[5], id)) %>%
  mutate (id = ifelse(row == "E" , id_all[6], id)) %>%
  mutate (id = ifelse(row == "F" , id_all[7], id)) %>%
  mutate ("%" = ifelse (group == "HBG", 0, 100))

# calculate mean fluorescence for all HBG groups to calculate relative fluorescence of target sample
mean_HBG1 <- Plate1_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluorescence = mean(fluorescence))

mean_HBG2 <- Plate2_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluorescence = mean(fluorescence))

mean_HBG3 <- Plate3_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluorescence = mean(fluorescence))

mean_HBG4 <- Plate4_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluorescence = mean(fluorescence))

mean_HBG5 <- Plate5_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluorescence = mean(fluorescence))

# calculate rel. fluorescence of all samples relative to their corresponding HBG values and combine data sets
Plate1_tidy_rel <- Plate1_tidy %>%
  mutate(rel_fluorescence = fluorescence / mean_HBG1$mean_fluorescence)

Plate2_tidy_rel <- Plate2_tidy %>%
  mutate(rel_fluorescence = fluorescence / mean_HBG2$mean_fluorescence)

Plate3_tidy_rel <- Plate3_tidy %>%
  mutate(rel_fluorescence = fluorescence / mean_HBG3$mean_fluorescence)

Plate4_tidy_rel <- Plate4_tidy %>%
  mutate(rel_fluorescence = fluorescence / mean_HBG4$mean_fluorescence)

Plate5_tidy_rel <- Plate5_tidy %>%
  mutate(rel_fluorescence = fluorescence / mean_HBG5$mean_fluorescence)

#combine tibbles
mtt_tidy <- rbind(Plate1_tidy_rel, Plate2_tidy_rel, Plate3_tidy_rel, Plate4_tidy_rel, Plate5_tidy_rel) %>%
  filter(id != "HBG") %>%
  filter(sample != "454") %>%
  filter (col != "X__10" | sample != "1106 + 100% DF" ) # exclude outlier

# change id to fator and reorder levels
mtt_tidy$id <- factor(mtt_tidy$id, levels = id_all)

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey
colours_core <- c(rep(colours[6], 5), rep(colours[5], 5))

#plots
p7B <- ggplot(mtt_tidy, aes(id, rel_fluorescence, group = group, fill = group ) ) + 
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position=position_dodge(0.9))+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  labs(
    x = "formulation", 
    y = "rel. metabolic activity [%] of HBG",
    title = NULL,
    subtitle = "MTT assay",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw() +
  facet_grid(~ `%`,
             scales = "free_x", 
             space = "free_x"
  ) + 
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
  ) +
  theme(
    axis.text.x=element_text(angle=45,hjust=1)
  ) +
  scale_fill_manual("siRNA",
                    values = c(colours[6], colours[5]),
                    labels = c("Ctrl", "GFP")
  )
# plots are assembled in file "multiplot.R"
