# stats - take variables from "Fig7_mtt.R"
# this script calculates ANOVA, student's t-tests and cohen's d

library(car)
library(sjstats)
library(tidyverse)

setwd() # choose the folder where the raw data is stored

# filter data for Anova
mtt_tidy_GFP_aov <- mtt_tidy %>%
  filter(group == "GFP") %>%
  filter(id != "core\npolyplex") # since "core" is missing the ligands, calculating an anova with it produces an error -> remove

mtt_tidy_ctrl_aov <- mtt_tidy %>%
  filter(group == "ctrl") %>%
  filter(id != "core\npolyplex")

# filter data for post-hoc tests
mtt_tidy_GFP_ttest<- mtt_tidy %>%
  filter(group == "GFP") %>%
  mutate(name = str_c(id, `%`))

mtt_tidy_ctrl_ttest<- mtt_tidy %>%
  filter(group == "ctrl") %>%
  mutate(name = str_c(id, `%`))

#factorial ANOVA: siGFP containing samples
mttAssay_RLU_Model_GFP <-aov(rel_fluorescence ~ `%`*id, data = mtt_tidy_GFP_aov)
anova_GFP <- Anova(mttAssay_RLU_Model_GFP, type="III") # type: Displays type 1, 2 oder 3 sums of squares
anova_GFP$`Pr(>F)` # access anova results (stored as matrix)
summary.lm(mttAssay_RLU_Model_GFP) # alternative way to summarize the anova
anova_stats(mttAssay_RLU_Model_GFP) # displays stats associated with ANOVA (df sumsq meansq statistic p.value etasq partial.etasq omegasq partial.omegasq cohens.f power)

#factorial ANOVA: sictrl containing samples
mttAssay_RLU_Model_ctrl<-aov(rel_fluorescence ~ `%`*id, data = mtt_tidy_ctrl_aov)
anova_Ctrl <- Anova(mttAssay_RLU_Model_ctrl, type="III")
anova_Ctrl$`Pr(>F)`
summary.lm(mttAssay_RLU_Model_ctrl)
anova_stats(mttAssay_RLU_Model_ctrl) # displays stats associated with ANOVA (df sumsq meansq statistic p.value etasq partial.etasq omegasq partial.omegasq cohens.f power)

# Post Hoc Analysis (CAVE: when interactions are significant, post hoc tests on the main result are missleading)
ttest_GFP <- pairwise.t.test(mtt_tidy_GFP_ttest$rel_fluorescence, mtt_tidy_GFP_ttest$name, p.adjust.method = "none")  #bonferroni oder holm correction 

values_GFP<-as.tibble(ttest_GFP$p.value[1:20,1]) %>% # access p values by their position in a matrix
  rename(p_value = value)

sample_GFP<-as.tibble(names(ttest_GFP$p.value[1:20,1])) %>%
  rename(sample = value)

postHoc_GFP_uncorrected <- cbind(values_GFP, sample_GFP)

ttest_ctrl <- pairwise.t.test(mtt_tidy_ctrl_ttest$rel_fluorescence, mtt_tidy_ctrl_ttest$name, p.adjust.method = "none")
values<-as.tibble(ttest_ctrl$p.value[1:20,1]) %>% # access p values by their position in a matrix
  rename(p_value = value)

sample<-as.tibble(names(ttest_ctrl$p.value[1:20,1])) %>%
  rename(sample = value)

postHoc_ctrl_uncorrected <- cbind(values, sample)

# p value correction (HOLM)
postHoc_GFP_corrected <- postHoc_GFP_uncorrected %>%
  mutate(p.adjusted = p.adjust( postHoc_GFP_uncorrected$p_value, method = "holm")) %>%
  arrange (-desc(p.adjusted))

postHoc_ctrl_corrected <- postHoc_ctrl_uncorrected %>%
  mutate(p.adjusted = p.adjust( postHoc_ctrl_uncorrected$p_value, method = "holm")) %>%
  arrange (-desc(p.adjusted))

# filter significant values
p_adjusted_sig_GFP <- postHoc_GFP_corrected %>% # only values with p.adjusted. <= 0.05
  filter(p.adjusted <= 0.05)%>%
  mutate(p.adjusted_rnd = round(p.adjusted, 3))

p_adjusted_sig_ctrl <- postHoc_GFP_corrected %>% # only values with p.adjusted. <= 0.05
  filter(p.adjusted <= 0.05) %>%
  mutate(p.adjusted_rnd = round(p.adjusted, 3))


