# This script imports data from *.xlsx files exported by Tecan Reader (Tecan Trading AG, Switzerland, Spark 10M, SparkControl V 2.1).
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)
library(readxl)

setwd() # choose the folder where the raw data is stored

#import raw data
Plate2 <- as.tibble(read_excel("20180707 EtBr Assay siRNA 991 1203 1223  1224_2.xlsx", range = "A25:M52", col_names = FALSE)) %>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D", "E", "F", "G", "H"))
Plate3 <- as.tibble(read_excel("20180707 EtBr Assay siRNA 991 1203 1223  1224_3.xlsx", range = "A25:M52", col_names = FALSE)) %>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D", "E", "F", "G", "H"))
Plate4 <- as.tibble(read_excel("20180707 EtBr Assay siRNA 991 1203 1223 1224.xlsx", range = "A25:M52", col_names = FALSE)) %>%
  filter(`X__1` == "Name" | `X__1` == "Gain" | `X__1` == "<>"| `X__1` == "Excitation wavelength"| `X__1` == "Emission wavelength" | `X__1` %in% c("A", "B", "C", "D", "E", "F", "G", "H"))

# make the data tidy
Plate2_tidy  <- Plate2 %>% 
  filter(`X__1` %in% c("A", "B", "C", "D", "E", "F", "G")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  select ("row", "col", "fluorescence" ) %>%
  filter (col %in% c("X__2", "X__3", "X__4", "X__5", "X__6", "X__7") | 
            row == "A" & col %in% c ("X__8", "X__9")) %>%
  mutate(formulation = ifelse(row %in% c ("B", "C", "D", "E", "F", "G"), "core shell", "core")) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__2", "neg. ctrl", formulation)) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__3", "pos. ctrl", formulation)) %>%
  mutate(shell = ifelse(row == "A", "none", "1203")) %>%
  mutate(shell = ifelse(row %in% c("E", "F", "G"), "1223", shell)) %>%
  mutate(`mol%` = ifelse(row %in% c("B","E"), 10, 0)) %>%
  mutate(`mol%` = ifelse(row %in% c("C","F"), 20, `mol%`)) %>%
  mutate(`mol%` = ifelse(row %in% c("D","G"), 30, `mol%`)) %>%
  mutate(heparin = ifelse(xor(col == "X__3" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__5" & row == "A"), 1, 0)) %>%
  mutate(heparin = ifelse(xor(col == "X__4" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__6" & row == "A"), 5, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__5" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__7" & row == "A"), 10, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__6" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__8" & row == "A"), 15, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__7" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__9" & row == "A"), 20, heparin)) %>%
  mutate (id = "p2")

Plate3_tidy  <- Plate3 %>% 
  filter(`X__1` %in% c("A", "B", "C", "D", "E", "F", "G")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  select ("row", "col", "fluorescence" ) %>%
  filter (col %in% c("X__2", "X__3", "X__4", "X__5", "X__6", "X__7") | 
            row == "A" & col %in% c ("X__8", "X__9")) %>%
  mutate(formulation = ifelse(row %in% c ("B", "C", "D", "E", "F", "G"), "core shell", "core")) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__2", "neg. ctrl", formulation)) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__3", "pos. ctrl", formulation)) %>%
  mutate(shell = ifelse(row == "A", "none", "1203")) %>%
  mutate(shell = ifelse(row %in% c("E", "F", "G"), "1223", shell)) %>%
  mutate(`mol%` = ifelse(row %in% c("B","E"), 10, 0)) %>%
  mutate(`mol%` = ifelse(row %in% c("C","F"), 20, `mol%`)) %>%
  mutate(`mol%` = ifelse(row %in% c("D","G"), 30, `mol%`)) %>%
  mutate(heparin = ifelse(xor(col == "X__3" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__5" & row == "A"), 1, 0)) %>%
  mutate(heparin = ifelse(xor(col == "X__4" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__6" & row == "A"), 5, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__5" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__7" & row == "A"), 10, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__6" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__8" & row == "A"), 15, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__7" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__9" & row == "A"), 20, heparin)) %>%
  mutate (id = "p3")

Plate4_tidy  <- Plate4 %>% 
  filter(`X__1` %in% c("A", "B", "C", "D", "E", "F", "G")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  rename("row" = `X__1`) %>%
  filter(!is.na(fluorescence)) %>%
  select ("row", "col", "fluorescence" ) %>%
  filter (col %in% c("X__2", "X__3", "X__4", "X__5", "X__6", "X__7") | 
            row == "A" & col %in% c ("X__8", "X__9")) %>%
  mutate(formulation = ifelse(row %in% c ("B", "C", "D", "E", "F", "G"), "core shell", "core")) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__2", "neg. ctrl", formulation)) %>%
  mutate(formulation = ifelse(row == "A" & col == "X__3", "pos. ctrl", formulation)) %>%
  mutate(shell = ifelse(row == "A", "none", "1203")) %>%
  mutate(shell = ifelse(row %in% c("E", "F", "G"), "1223", shell)) %>%
  mutate(`mol%` = ifelse(row %in% c("B","E"), 10, 0)) %>%
  mutate(`mol%` = ifelse(row %in% c("C","F"), 20, `mol%`)) %>%
  mutate(`mol%` = ifelse(row %in% c("D","G"), 30, `mol%`)) %>%
  mutate(heparin = ifelse(xor(col == "X__3" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__5" & row == "A"), 1, 0)) %>%
  mutate(heparin = ifelse(xor(col == "X__4" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__6" & row == "A"), 5, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__5" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__7" & row == "A"), 10, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__6" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__8" & row == "A"), 15, heparin)) %>%
  mutate(heparin = ifelse(xor(col == "X__7" & row %in% c("B", "C", "D", "E", "F", "G"), col == "X__9" & row == "A"), 20, heparin)) %>%
  mutate (id = "p4")

#combine data sets
EtBr_tidy <- rbind (Plate2_tidy, Plate3_tidy, Plate4_tidy)

# extract control values
pos_ctrls <- EtBr_tidy %>%
  filter (formulation == "pos. ctrl") %>%
  mutate (fluorescence = as.double(fluorescence))

neg_ctrls <- EtBr_tidy %>%
  filter (formulation == "neg. ctrl") %>%
  mutate (fluorescence = as.double(fluorescence))

#choose data for plotting
EtBr_plot <- EtBr_tidy %>%
  filter(xor(`mol%` == 20, formulation == "core") ) %>%
  filter(heparin != 20) %>%
  mutate (fluorescence = as.double(fluorescence)) %>%
  mutate (fluorescence = ifelse(id == "p2",fluorescence - neg_ctrls$fluorescence[1], fluorescence - neg_ctrls$fluorescence[2])) %>%
  mutate (fluorescence = ifelse(id == "p4",fluorescence - neg_ctrls$fluorescence[3], fluorescence)) %>%
  mutate (rel_fluor = ifelse(id == "p2", fluorescence / pos_ctrls$fluorescence[1],fluorescence / pos_ctrls$fluorescence[2] )) %>%
  mutate (rel_fluor = ifelse(id == "p4", fluorescence / pos_ctrls$fluorescence[3], rel_fluor )) 

# change heparin to factor to have a discrete x-axis
EtBr_plot$heparin <- as.factor(EtBr_plot$heparin)

# define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey


#plots
pSI_EtBr  <- ggplot(EtBr_plot, aes(heparin, rel_fluor, fill = shell) ) + 
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(stat = "summary", fun.data = mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  labs(
    x = "heparin [IU/ml]", 
    y = "fluorescence [%] of pos. ctrl",
    title = "Ethidium bromide displacement assay",
    subtitle = "Core - lipid anchor (LA, LAE) polyplexes",
    colour = NULL,
    fill = NULL,
    tag = NULL
  ) +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(-0.2, 1.5)
  ) +
  theme_bw() +
  theme(
    legend.position = c(0.1, 0.75),
    legend.background = element_rect(size = 0.5, colour = "grey50")
  )+
  scale_fill_manual("lipid anchor",
                    values = c(colours[1], colours[3],colours[5] ), 
                    labels = c("LA", "LAE", "none")
  )

# safe plot as .png    
ggsave("Supporting_figure_17_EtBr.png", plot = pSI_EtBr,  width = 16, height = 9, units = c("cm"), dpi = 300) 

